/* pong-tool: pong tool
 * Author: George Lebl
 * (c) 1999 the Free Software Foundation
 * (c) 2000 Eazel, Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#include "config.h"
#include <string.h>
#include <gnome.h>
#include "../pong/pong.h"
#include "../pong/pongpane.h"
#include "../pong/pongparser.h"
#include "../pong/pongutil.h"
#include "../pong/pong-strings.h"

static PongFile *pong_file = NULL;

static const struct poptOption options[] = {
	{ NULL } 
};

static void
print_string (const char *string)
{
	if (string != NULL)
		printf ("gchar *s = N_(\"%s\");\n", string);
}

static void
print_plug (PongPlugWidget *widget)
{
	print_string (widget->base.label);
}

static void
print_widget (PongWidget *widget)
{
	GList *li;

	print_string (widget->base.label);
	print_string (widget->tooltip);

	for (li = widget->arguments; li != NULL; li = li->next) {
		PongArgument *arg = li->data;

		if (arg->value_translatable)
			print_string (arg->value);
	}

	for (li = widget->options; li != NULL; li = li->next) {
		PongOption *opt = li->data;
		
		print_string (opt->label);
	}
}

static void
print_group (PongGroup *group)
{
	GList *li;

	print_string (group->base.label);

	for (li = group->widgets; li != NULL; li = li->next) {
		PongWidget *widget = li->data;

		if (widget->base.type == PONG_PLUG_WIDGET)
			print_plug ((PongPlugWidget *)widget);
		else
			print_widget (widget);
	}
}

static void
print_pane (PongPane *pane)
{
	GList *li;

	print_string (pane->base.label);

	for (li = pane->groups; li != NULL; li = li->next) {
		PongGroup *group = li->data;

		if (group->base.type == PONG_PLUG_WIDGET)
			print_plug ((PongPlugWidget *)group);
		else
			print_group (group);
	}
}

static void
print_file (PongFile *file)
{
	GList *li;

	print_string (pong_file->dialog_title);
	print_string (pong_file->help_path);

	for (li = file->panes; li != NULL; li = li->next) {
		PongPane *pane = li->data;
		print_pane (pane);
	}
}

int
main (int argc, char *argv[])
{
	poptContext ctx;
	const char **args;
	const char *file;
	char *found_file;

	gnomelib_init ("pong-gettext-tool", VERSION);

	ctx = gnomelib_parse_args (argc, argv, 0);

	if ( ! pong_init ())
		g_error (_("PonG init failed!"));

	args = poptGetArgs (ctx);

	if (args == NULL ||
	    args[0] == NULL ||
	    args[1] != NULL) {
		g_warning (_("You must supply one argument, "
			     "the .pong file to read."));
		exit (1);
	}

	file = args[0];

	found_file = pong_find_file (file, NULL);
	if (found_file == NULL) {
		g_warning (_("Cannot find %s"), file);
		exit (1);
	}

	pong_file = pong_file_load_xml (found_file,
					TRUE /*no_i18n*/,
					FALSE /*use_gettext*/,
					NULL /*gettext_domain*/,
					TRUE /*bogus_types*/);
	if (pong_file == NULL) {
		g_warning (_("Can't load pong file: %s"), found_file);
		exit (1);
	}

	printf ("/*\n"
		" * Translatable strings file generated by pong-gettext-tool.\n"
		" * Add this file to your project's POTFILES.in.\n"
		" * DO NOT compile it as part of your application.\n"
		" */\n\n");

	print_file (pong_file);

	return 0;
}
