/* PonG: Glade support
 * Author: George Lebl
 * (c) 2000 Eazel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include "config.h"
#include <gnome.h>
#include <glade/glade.h>

#include "pongutil.h"

#include "pong-xml.h"
#include "pong-ui-internal.h"
#include "pong-ui-plug-glade.h"

#include "pong-glade.h"

/* directories to look up glade files in */
GList *pong_glade_directories = NULL;

/* function that gets new GladeXML objects */
PongGetGladeXML pong_glade_default_getter = NULL;
gpointer pong_glade_default_getter_data = NULL;
GDestroyNotify pong_glade_default_getter_data_destroy = NULL;

gboolean
pong_glade_init (void)
{
	if ( ! pong_init ())
		return FALSE;

	pong_add_plug_creator (pong_ui_plug_glade_new);

	glade_gnome_init ();

	return TRUE;
}

void
pong_add_glade_directory (const char *directory)
{
	pong_glade_directories = g_list_append (pong_glade_directories,
						g_strdup (directory));
}

/* Find a glade file in the same directories as pong looks in, utility
 * for glade using audience */
char *
pong_find_glade_file (const char *file)
{
	g_return_val_if_fail (file != NULL, NULL);

	return pong_find_file (file, pong_glade_directories);
}

/* 
 * Glade files in memory, support
 */
void
pong_set_default_glade_getter (PongGetGladeXML getter,
			       gpointer data,
			       GDestroyNotify destroy_notify)
{
	if (pong_glade_default_getter_data_destroy != NULL)
		pong_glade_default_getter_data_destroy
			(pong_glade_default_getter_data);

	pong_glade_default_getter = getter;
	pong_glade_default_getter_data = data;
	pong_glade_default_getter_data_destroy = destroy_notify;
}
